run_browser

Function run_browser 

pub fn run_browser(
    host_state: HostState,
    status: Arc<Mutex<PageStatus>>,
) -> Result<()>
Start the Oxide desktop shell: GPUI event loop and one main window.

Call this after constructing a crate::runtime::BrowserHost and cloning its HostState and status mutex, as the oxide binary does. This function does not return until the application exits.